@@ -63,15 +63,24 @@ iris_callback (gpointer data)
   gint i;
   gint width_step;
   gint height_step;
+  gint width;
+  gint height;
 
   width_step = MIN (iris_rect.width / 2, iris_block);
   height_step = MIN (iris_rect.width / 2, iris_block);
 
   for (i = 0; i < MIN (width_step, height_step); i++)
-    gdk_draw_rectangle (GDK_ROOT_PARENT (), iris_gc, FALSE,
-			iris_rect.x + i, iris_rect.y + i,
-			(gint)iris_rect.width - 2 * i,
-			(gint)iris_rect.height - 2 * i);
+    {
+      width  = (gint)iris_rect.width  - 2 * i;
+      height = (gint)iris_rect.height - 2 * i;
+
+      if (width < 0 || height < 0)
+        break;
+
+      gdk_draw_rectangle (GDK_ROOT_PARENT (), iris_gc, FALSE,
+                          iris_rect.x + i, iris_rect.y + i,
+                          width, height);
+    }
 
   gdk_flush ();
 
@@ -222,7 +231,7 @@ display_gui (void)
   box = gtk_message_dialog_new (NULL, 0,
 				GTK_MESSAGE_QUESTION,
 				GTK_BUTTONS_NONE,
-				_("Really log out?"));
+				_("Are you sure you want to log out?"));
 
   gtk_dialog_add_button (GTK_DIALOG (box), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
   gtk_dialog_add_button (GTK_DIALOG (box), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
@@ -239,7 +248,7 @@ display_gui (void)
 
   if (!autosave)
     {
-      toggle_button = gtk_check_button_new_with_label (_("Save current setup"));
+      toggle_button = gtk_check_button_new_with_mnemonic (_("_Save current setup"));
       gtk_widget_show (toggle_button);
       gtk_box_pack_start (GTK_BOX (GTK_DIALOG (box)->vbox),
 			  toggle_button,
@@ -267,13 +276,13 @@ display_gui (void)
       action_vbox = gtk_vbox_new (FALSE, 0);
       gtk_container_add (GTK_CONTAINER (frame), action_vbox);
 
-      r = gtk_radio_button_new_with_label (NULL, _("Logout"));
+      r = gtk_radio_button_new_with_mnemonic (NULL, _("_Log Out"));
       gtk_box_pack_start (GTK_BOX (action_vbox), r, FALSE, FALSE, 0);
 
-      r = halt = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (r), _("Shut Down"));
+      r = halt = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (r), _("Sh_ut Down"));
       gtk_box_pack_start (GTK_BOX (action_vbox), r, FALSE, FALSE, 0);
 
-      r = reboot = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (r), _("Reboot"));
+      r = reboot = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (r), _("_Restart the computer"));
       gtk_box_pack_start (GTK_BOX (action_vbox), r, FALSE, FALSE, 0);
     }
   g_free (s);
@@ -285,6 +294,10 @@ display_gui (void)
   gdk_pointer_grab (box->window, TRUE, 0,
 		    NULL, NULL, GDK_CURRENT_TIME);
   gdk_keyboard_grab (box->window, FALSE, GDK_CURRENT_TIME);
+  XSetInputFocus (GDK_DISPLAY (),
+		  GDK_WINDOW_XWINDOW (box->window),
+		  RevertToParent,
+		  CurrentTime);
 
   response = gtk_dialog_run (GTK_DIALOG (box));
 
