@@ -325,7 +325,7 @@ free_client (Client *client)
 }
 
 /* Run a command on a client. */
-gint
+static int
 run_command_prop (Client     *client, 
 		  const char *command, 
 		  SmProp     *prop)
@@ -1504,7 +1504,7 @@ client_clean_up (Client* client)
 	  start_client (client);
 	else
 	  {
-	    gchar *message = _("Respawn abandoned due to failures.");
+	    gchar *message = _("Restart abandoned due to failures.");
 	    /* This is a candidate for a confirm = TRUE. */
 	    client_reasons (client, FALSE, 1, &message); 
 	    client_event (client->handle, GsmRemove);
